<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage  Charity Give
 * @since  Charity Give 1.0.0
 * @return array An array of default values
 */

function charity_give_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$charity_give_default_options = array(
		// Color Options
		'header_title_color'			    => '#000',
		'header_tagline_color'			    => '#000',
		'header_txt_logo_extra'			    => 'show-all',
		'colorscheme_hue'				    => '#d87b4d',
		'colorscheme'					    => 'default',
		'theme_version'						=> 'lite-version',
		'home_layout'						=> 'default-design',

		// typography Options
		'theme_typography' 				    => 'default',
		'body_theme_typography' 		    => 'default',
		
		// loader
		'loader_enable'         		    => (bool) false,
		'loader_icon'         			    => 'default',

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',
				
		// homepage options
		'enable_frontpage_content' 			=> false,

		// blog/archive options
		'archive_btn_txt' 		    		=> esc_html__( 'Read More', 'charity-give' ),

		// layout 
		'site_layout'         			      => 'wide',
		'sidebar_position'         		      => 'right-sidebar',
		'post_sidebar_position' 		      => 'right-sidebar',
		'page_sidebar_position' 		      => 'right-sidebar',
		'search_icon_in_primary_menu_enable'  => (bool) true,
		'nav_btn'						      => (bool) false,
		'nav_btn_txt' 					      => esc_html__( 'Donate Now', 'charity-give' ),
		'nav_btn_url' 					      => '#',
		'search_from_enable'                  => (bool) true,

		// excerpt options
		'long_excerpt_length'               => 25,

		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// footer options
		'copyright_text'           		    => sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'charity-give' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'charity-give' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'charity-give' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	    => (bool) true,

		// reset options
		'reset_options'      			    => (bool) false,
		
		// homepage sections sortable
		'default_sortable' 			    	=> 'featured_slider,featured,about,promotion,gallery,donation,latest_posts,sponsor',


		// blog/archive options
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'charity-give' ),
		'hide_archive_post_image'		    => false,		
		'hide_archive_title'			    => false,
		'hide_archive_date'			   		=> (bool) false,
		'hide_archive_content'			   	=> (bool) false,


		// single post theme options
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,
		'single_post_hide_category'		    => (bool) false,
		'single_post_hide_tags'			    => (bool) false,

		/* Front Page */

		// top bar
		'topbar_section_enable'			=> (bool) false,
		'secondary_menu_enable'			=> (bool) true,
		'social_menu_enable'			=> (bool) true,

		// featured slider
		'featured_slider_section_enable'	    => (bool) false,
		'featured_slider_autoplay'				=> (bool) false,
		'featured_slider_btn_text'			    => esc_html__( 'Learn More', 'charity-give' ),
		'featured_slider_alt_btn_text'			=> esc_html__( 'Donate', 'charity-give' ),
		'featured_slider_alt_btn_url'			=> '#',
		'featured_slider_excerpt_length'		=> 25,

		//featured 
		'featured_section_enable'	            => (bool) false,
		'featured_btn_text'			            => esc_html__( 'Read More', 'charity-give' ),
		'featured_title'			            => esc_html__( 'Together to help the world better!', 'charity-give' ),
		'featured_description'			        => esc_html__( 'Please help us change lives around the world.', 'charity-give' ),

	   	// about
		'about_section_enable'			        => (bool) false,
		'about_btn_text'			            => esc_html__( 'Learn More', 'charity-give' ),
		'about_excerpt_length'		            => 25,

	   // promotion
	   'promotion_section_enable'			    => false,
	   'promotion_title'					    => esc_html__( 'Your Vision. Your Passion', 'charity-give' ),
	   'promotion_btn'					        => esc_html__( 'Appointment', 'charity-give' ),
	   'promotion_description'				    => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis...', 'charity-give' ),


		// gallery
		'gallery_section_enable'	            => (bool) false,
		'gallery_count'				            => 6,
		'gallery_title'				            => esc_html__( 'Some Outstanding Activities', 'charity-give' ),
		'gallery_sub_title'				        => esc_html__( 'Children and poor people are at high risk of severe malnutrition & no education.', 'charity-give' ),
		'gallery_btn_title'			            => esc_html__( 'View More', 'charity-give' ),

		// donation
		'donation_section_enable'	            => (bool) false,
		'donation_count'					    => 3,
		'donation_title'					    => esc_html__( 'FOCUSED CAUSES', 'charity-give' ),
		'donation_sub_title'                    => esc_html__( 'Children and poor people are at high risk of severe malnutrition & no education.', 'charity-give' ),
		'donation_btn_title'				    => esc_html__( 'Donate Now', 'charity-give' ),
		'donation_read_more_btn_title'	        => esc_html__( 'Read More', 'charity-give' ),


		// latest_posts section
		'latest_posts_section_enable'		    => false,
		'latest_posts_excerpt_length'			=> 25,
		'latest_posts_title'				    => esc_html__( 'Latest News Update', 'charity-give' ),
		'latest_posts_sub_title'				=> esc_html__( 'Children and poor people are at high risk of severe malnutrition & no education.', 'charity-give' ),
		'latest_posts_btn'				        => esc_html__( 'Read More', 'charity-give' ),

		// sponsor
		'sponsor_section_enable'		        => (bool) false,
		'sponsor_title'					        => esc_html__( 'Our Partner', 'charity-give' ),
		'sponsor_sub_title'				        => esc_html__( 'Welcome to the dedicated to building remarkable Schedule!', 'charity-give' ),


	);

	$output = apply_filters( 'charity_give_default_theme_options', $charity_give_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}