<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage  Charity Give
 * @since  Charity Give 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function charity_give_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'charity-give' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function charity_give_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'charity-give' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}


/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function charity_give_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'charity-give' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

/**
 * List of events for post choices.
 * @return Array Array of post ids and name.
 */
function charity_give_donation_form_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'give_forms' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'charity-give' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'charity_give_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function charity_give_site_layout() {
        $charity_give_site_layout = array(
            'wide'          => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
            'boxed-layout'  => esc_url( get_template_directory_uri() . '/assets/images/boxed.png' ),
        );

        $output = apply_filters( 'charity_give_site_layout', $charity_give_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'charity_give_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function charity_give_selected_sidebar() {
        $charity_give_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'charity-give' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'charity-give' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'charity-give' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'charity-give' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'charity-give' ),
        );

        $output = apply_filters( 'charity_give_selected_sidebar', $charity_give_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'charity_give_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function charity_give_global_sidebar_position() {
        $charity_give_global_sidebar_position = array(
            'right-sidebar' => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'no-sidebar'    => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
        );

        $output = apply_filters( 'charity_give_global_sidebar_position', $charity_give_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'charity_give_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function charity_give_sidebar_position() {
        $charity_give_sidebar_position = array(
            'right-sidebar'         => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'no-sidebar-content'    => esc_url( get_template_directory_uri() . '/assets/images/boxed.png' ),
        );

        $output = apply_filters( 'charity_give_sidebar_position', $charity_give_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'charity_give_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function charity_give_pagination_options() {
        $charity_give_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'charity-give' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'charity-give' ),
        );

        $output = apply_filters( 'charity_give_pagination_options', $charity_give_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'charity_give_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function charity_give_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'charity-give' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'charity-give' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'charity-give' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'charity-give' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'charity-give' ),
            'spinner-dots'          => esc_html__( 'Dots', 'charity-give' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'charity-give' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'charity-give' ),
        );
        return apply_filters( 'charity_give_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'charity_give_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function charity_give_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'charity-give' ),
            'off'       => esc_html__( 'Disable', 'charity-give' )
        );
        return apply_filters( 'charity_give_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'charity_give_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function charity_give_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'charity-give' ),
            'off'       => esc_html__( 'No', 'charity-give' )
        );
        return apply_filters( 'charity_give_hide_options', $arr );
    }
endif;