<?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Charity Give
 * @since Charity Give 1.0.0
 */
if ( ! function_exists( 'charity_give_add_about_section' ) ) :
    /**
    * Add slider section
    *
    *@since Charity Give 1.0.0
    */
    function charity_give_add_about_section() {
    	$options = charity_give_get_theme_options();
        // Check if slider is enabled on frontpage
        $about_enable = apply_filters( 'charity_give_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'charity_give_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        charity_give_render_about_section( $section_details );
    

    }
endif;

if ( ! function_exists( 'charity_give_get_about_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Charity Give 1.0.0
    * @param array $input slider section details.
    */
    function charity_give_get_about_section_details( $input ) {
        $options = charity_give_get_theme_options();

        $content = array();
        $page_ids = array();

        for ( $i = 1; $i <= 2; $i++ ) {
            if ( ! empty( $options['about_content_page_' . $i] ) )
                $page_ids[] = $options['about_content_page_' . $i];
        }

        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => 2,
            'orderby'           => 'post__in',
        );                    


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = charity_give_trim_content( $options['about_excerpt_length'] );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'charity_give_filter_about_section_details', 'charity_give_get_about_section_details' );


if ( ! function_exists( 'charity_give_render_about_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Charity Give 1.0.0
   *
   */
   function charity_give_render_about_section( $content_details = array() ) {
        $options = charity_give_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="charity_give_about_section" class="relative page-section">
            <?php if ( is_customize_preview()):
                charity_give_section_tooltip( 'charity_give_about_section' );
            endif; ?>
            <div class="wrapper">
                <?php foreach ( $content_details as $i => $content ) : ?>
                    <article class="has-post-thumbnail">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                        </div><!-- .featured-image -->

                        <div class="entry-container">
                            <div class="section-header">
                                <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                <?php if ( $options['about_sub_title_' . ($i+1)] ) : ?>
                                    <p class="section-subtitle"><?php echo esc_html( $options['about_sub_title_' . ($i+1)] ); ?></p>
                                <?php endif; ?>
                            </div><!-- .section-header -->

                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->

                            <div class="read-more">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['about_btn_text'] ); ?></a>
                        </div><!-- .read-more -->
                        </div><!-- .entry-container -->
                    </article>
                <?php endforeach; ?>
            </div><!-- .wrapper -->
        </div><!-- #about-section -->
    <?php }
endif;