<?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Charity Give
 * @since Charity Give 1.0.0
 */
if ( ! function_exists( 'charity_give_add_featured_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Charity Give 1.0.0
    */
    function charity_give_add_featured_slider_section() {
    	$options = charity_give_get_theme_options();
        // Check if slider is enabled on frontpage
        $featured_slider_enable = apply_filters( 'charity_give_section_status', true, 'featured_slider_section_enable' );

        if ( true !== $featured_slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'charity_give_filter_featured_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        charity_give_render_featured_slider_section( $section_details );
    

    }
endif;

if ( ! function_exists( 'charity_give_get_featured_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Charity Give 1.0.0
    * @param array $input slider section details.
    */
    function charity_give_get_featured_slider_section_details( $input ) {
        $options = charity_give_get_theme_options();

        $content = array();
        $page_ids = array();

        for ( $i = 1; $i <= 3; $i++ ) {
            if ( ! empty( $options['featured_slider_content_page_' . $i] ) )
                $page_ids[] = $options['featured_slider_content_page_' . $i];
        }
        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => 3,
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
        );                    


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = charity_give_trim_content( $options['featured_slider_excerpt_length'] );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'charity_give_filter_featured_slider_section_details', 'charity_give_get_featured_slider_section_details' );


if ( ! function_exists( 'charity_give_render_featured_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Charity Give 1.0.0
   *
   */
   function charity_give_render_featured_slider_section( $content_details = array() ) {
        $options = charity_give_get_theme_options();
        $autoplay = $options['featured_slider_autoplay'] ? 'true' : 'false';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="charity_give_featured_slider_section" class="slider-section">
            <?php if ( is_customize_preview()):
                charity_give_section_tooltip( 'charity_give_featured_slider_section' );
            endif; ?>
            <div class="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": true, "arrows":false, "<?php echo esc_attr( $autoplay ); ?>": false, "draggable": true, "fade": false, "adaptiveHeight": true }'>
                <?php foreach ($content_details as $content ): ?>
                    <article style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                        <div class="overlay"></div>
                        <div class="wrapper">
                            <div class="featured-content-wrapper">
                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->

                                    <div class="read-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn one"><?php echo esc_html( $options['featured_slider_btn_text'] ); ?></a>
                                        <?php if ( $options['featured_slider_alt_btn_text'] && $options['featured_slider_alt_btn_url'] ) : ?>
                                        <a href="<?php echo esc_url( $options['featured_slider_alt_btn_url'] ); ?>" class="btn two"><?php echo esc_html( $options['featured_slider_alt_btn_text'] ); ?></a>
                                    <?php endif; ?>
                                    </div><!-- .read-more -->
                                </div><!-- .entry-container -->
                            </div><!-- .featured-content-wrapper -->
                        </div><!-- .wrapper -->
                    </article>
                <?php endforeach; ?>
            </div><!-- .featured-slider -->
        </div><!-- #charity_give_featured_slider_section -->
    <?php }
endif;