<?php
/**
 * gallery section
 *
 * This is the template for the content of gallery section
 *
 * @package Theme Palace
 * @subpackage Charity Give
 * @since Charity Give 1.0.0
 */
if ( ! function_exists( 'charity_give_add_gallery_section' ) ) :
    /**
    * Add gallery section
    *
    *@since Charity Give 1.0.0
    */
    function charity_give_add_gallery_section() {
        $options = charity_give_get_theme_options();

        // Check if gallery is enabled on frontpage
        $gallery_enable = apply_filters( 'charity_give_section_status', true, 'gallery_section_enable' );

        if ( true !== $gallery_enable ) {
           return false;
        }
        // Get gallery section details
        $section_details = array();
        $section_details = apply_filters( 'charity_give_filter_gallery_section_details', $section_details );
        if ( empty( $section_details ) ) {
           return;
        }
        // Render gallery section now.
        charity_give_render_gallery_section( $section_details );
    }
endif;

if ( ! function_exists( 'charity_give_get_gallery_section_details' ) ) :
    /**
    * gallery section details.
    *
    * @since Charity Give 1.0.0
    * @param array $input gallery section details.
    */
    function charity_give_get_gallery_section_details( $input ) {
        $options = charity_give_get_theme_options();

        $content = array();
        $cat_id = ! empty( $options['gallery_category'] ) ? $options['gallery_category'] : '';
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => 6,
            'cat'               => absint( $cat_id ),
            'ignore_sticky_posts'   => true,
        );                    


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                    // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }        return $input;
    }
endif;
// gallery section content details.
add_filter( 'charity_give_filter_gallery_section_details', 'charity_give_get_gallery_section_details' );


if ( ! function_exists( 'charity_give_render_gallery_section' ) ) :
  /**
   * Start gallery section
   *
   * @return string gallery content
   * @since Charity Give 1.0.0
   *
   */
   function charity_give_render_gallery_section( $content_details = array() ) {
        $options = charity_give_get_theme_options();
        $gallery_title = ! empty( $options['gallery_title'] ) ? $options['gallery_title'] : '';
        $gallery_btn = ! empty( $options['gallery_btn_title'] ) ? $options['gallery_btn_title'] : '';
        
        ?>

        <div id="charity_give_gallery_section" class="relative page-section">
            <?php if ( is_customize_preview()):
                charity_give_section_tooltip( 'charity_give_gallery_section' );
            endif; ?>
            <div class="wrapper">
                <?php if ( !empty( $options['gallery_title'] ) || !empty( $options['gallery_sub_title'] ) ) : ?>
                    <div class="section-header">
                        <div class="section-header">
                            <?php if( !empty( $gallery_title ) ): ?>
                                <h2 class="section-title"><?php echo esc_html( $gallery_title ); ?></h2>
                            <?php endif; ?>
                            <?php if( !empty( $options['gallery_sub_title'] ) ): ?>
                                <p class="section-subtitle"><?php echo esc_html( $options['gallery_sub_title'] ); ?></p>
                            <?php endif; ?>
                        </div><!-- .section-header -->
                    </div><!-- .section-header-wrapper -->
                <?php endif; ?>

                <div class="section-content col-3 clear">
                    <div class="tab-content active">
                        <?php foreach ( $content_details as $content ) : ?>
                            <article class="has-post-thumbnail">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                    </header>
                                </div><!-- .featured-image -->
                            </article>
                        <?php endforeach; ?>
                    </div>
                </div><!-- .section-content -->
                <?php if( !empty( $options['gallery_btn_url'] ) && !empty( $gallery_btn ) ): ?>
                <div class="read-more">
                    <a href="<?php echo esc_url( $options['gallery_btn_url'] ); ?>" class="btn"><?php echo esc_html( $gallery_btn ); ?></a>
                </div><!-- .read-more -->
            <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #biopexel_gallery_section -->

    <?php }
endif;