<?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Charity Give
 * @since Charity Give 1.0.0
 */
if ( ! function_exists( 'charity_give_add_latest_posts_section' ) ) :
    /**
    * Add slider section
    *
    *@since Charity Give 1.0.0
    */
    function charity_give_add_latest_posts_section() {
    	$options = charity_give_get_theme_options();
        // Check if slider is enabled on frontpage
        $latest_posts_enable = apply_filters( 'charity_give_section_status', true, 'latest_posts_section_enable' );

        if ( true !== $latest_posts_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'charity_give_filter_latest_posts_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        charity_give_render_latest_posts_section( $section_details );
    

    }
endif;

if ( ! function_exists( 'charity_give_get_latest_posts_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Charity Give 1.0.0
    * @param array $input slider section details.
    */
    function charity_give_get_latest_posts_section_details( $input ) {
        $options = charity_give_get_theme_options();

        $content = array();
        $post_ids = array();

        for ( $i = 1; $i <= 3; $i++ ) {
            if ( ! empty( $options['latest_posts_content_post_' . $i] ) )
                $post_ids[] = $options['latest_posts_content_post_' . $i];
        }
        $args = array(
            'post_type'         => 'post',
            'post__in'          => ( array ) $post_ids,
            'posts_per_page'    => 3,
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
        );                    


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = charity_give_trim_content( $options['latest_posts_excerpt_length'] );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                    // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'charity_give_filter_latest_posts_section_details', 'charity_give_get_latest_posts_section_details' );


if ( ! function_exists( 'charity_give_render_latest_posts_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Charity Give 1.0.0
   *
   */
   function charity_give_render_latest_posts_section( $content_details = array() ) {
        $options = charity_give_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="charity_give_latest_posts_section" class="relative page-section">
            <div class="wrapper">
                <?php if ( is_customize_preview()):
                    charity_give_section_tooltip( 'charity_give_latest_posts_section' );
                endif; ?>
                <div class="section-header">
                    <?php if ( $options['latest_posts_title'] ) : ?>
                        <h2 class="section-title"><?php echo esc_html( $options['latest_posts_title'] ); ?></h2>
                    <?php endif; ?>
                    <?php if ( $options['latest_posts_sub_title'] ) : ?>
                        <p class="section-subtitle"><?php echo esc_html( $options['latest_posts_sub_title'] ); ?></p>
                    <?php endif; ?>
                </div><!-- .section-header -->

                <div class="archive-blog-wrapper col-3 clear">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="post-wrapper">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']);?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <span class="posted-on">
                                        <?php charity_give_posted_on($content['id']); ?>
                                    </span><!-- .posted-on -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>" tabindex="0"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->

                                    <?php if ( $options['latest_posts_btn'] ) : ?>
                                        <div class="read-more">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['latest_posts_btn'] ); ?></a>
                                        </div><!-- .read-more -->
                                    <?php endif; ?>
                                </div><!-- .entry-container -->
                            </div><!-- .post-wrapper -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #latest-posts-section -->
    <?php }
endif;