<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage  Charity Give
 * @since  Charity Give 1.0.0
 */

$options = charity_give_get_theme_options();  


if ( ! function_exists( 'charity_give_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since  Charity Give 1.0.0
	 */
	function charity_give_doctype() {
		?>
		<!DOCTYPE html>
		<html <?php language_attributes(); ?>>
		<?php
	}
endif;
add_action( 'charity_give_doctype', 'charity_give_doctype', 10 );


if ( ! function_exists( 'charity_give_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since  Charity Give 1.0.0
	 *
	 */
	function charity_give_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="profile" href="https://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
		<link rel="pingback" href="<?php echo esc_url( get_bloginfo( 'pingback_url' ) ); ?>">
	<?php endif;
}
endif;
add_action( 'charity_give_before_wp_head', 'charity_give_head', 10 );

if ( ! function_exists( 'charity_give_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since  Charity Give 1.0.0
	 *
	 */
	function charity_give_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'charity-give' ); ?></a>
			<?php
		}
	endif;
	add_action( 'charity_give_page_start_action', 'charity_give_page_start', 10 );

	if ( ! function_exists( 'charity_give_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since  Charity Give 1.0.0
	 *
	 */
	function charity_give_page_end() {
		?>
	</div><!-- #page -->
	<?php
}
endif;
add_action( 'charity_give_page_end_action', 'charity_give_page_end', 10 );

if ( ! function_exists( 'charity_give_topbar' ) ) :
	/**
	 * Topbar html codes
	 *
	 * @since Charity Give 1.0.0
	 *
	 */
	function charity_give_topbar() {
		$options = charity_give_get_theme_options(); 

		if ( $options['topbar_section_enable'] == true ) :
			?>
			<div id="top-navigation" class="relative">
				<div class="wrapper">
					<nav id="secondary-navigation" class="main-navigation" role="navigation" aria-label="Primary Menu">

						<?php if(has_nav_menu( 'secondary' ) && $options['secondary_menu_enable']) : ?>
							<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
								<span class="menu-label"><?php esc_html_e('Top', 'charity-give'); ?></span>

								<?php
								echo charity_give_get_svg( array( 'icon' => 'menu', 'class' => 'icon-menu' ) );
								echo charity_give_get_svg( array( 'icon' => 'close', 'class' => 'icon-menu' ) );
								?>
								
							</button>

							<?php 
							wp_nav_menu(  array(
								'theme_location' => 'secondary',
								'menu_class' => 'menu nav-menu',
								'container'=> false,
								'menu_id'	=>'secondary-menu',
								'echo' => true,
								'fallback_cb' => false,
								) );
							
							endif; 

							if($options['social_menu_enable'] && has_nav_menu( 'social' )):

								wp_nav_menu(  array(
									'theme_location' => 'social',
									'container' => 'div',
									'container_class' => 'social-icons',
									'echo' => true,
									'depth' => 1,
									'link_before' => '<span class="screen-reader-text">',
									'link_after' => '</span>',
									'fallback_cb' => false,
									) );

							endif;
							?>
						</nav><!-- .main-navigation-->
					</div><!-- .wrapper -->
				</div><!-- #top-navigation -->

			<?php endif; ?>
		<?php
	}
endif;
add_action( 'charity_give_header_action', 'charity_give_topbar', 9 );

if ( ! function_exists( 'charity_give_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since  Charity Give 1.0.0
	 *
	 */
	function charity_give_site_branding() {
		$options  = charity_give_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];	 ?>
		<header id="masthead" class="site-header" role="banner">
			<div class="wrapper">
			<div class="site-branding">
				<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
					<div class="site-logo">
						<?php the_custom_logo(); ?>
					</div>
				<?php } 
				if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
					<div id="site-identity">
						<?php
						if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
							if ( charity_give_is_latest_posts() || charity_give_is_frontpage() ) : ?>
								<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
							<?php else : ?>
								<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
								<?php
							endif;
						} 
						if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
							$description = get_bloginfo( 'description', 'display' );
							if ( $description || is_customize_preview() ) : ?>
								<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
								<?php
							endif; 
						}?>
					</div>
				<?php endif; ?>
			</div><!-- .site-branding -->

			<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="Primary Menu">
				<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
					<span class="menu-label"><?php esc_html_e( 'Menu', 'charity-give' ); ?></span>
					<?php
					echo charity_give_get_svg( array( 'icon' => 'menu' ) );
					echo charity_give_get_svg( array( 'icon' => 'close' ) );
					?>					
				</button>

				<?php  
				$search = '';
				if ( $options['search_icon_in_primary_menu_enable'] ) :
					$search = '<li class="search-menu"><a href="#">';
					$search .= charity_give_get_svg( array( 'icon' => 'search' ) );
					$search .= charity_give_get_svg( array( 'icon' => 'close' ) );
					$search .= '</a><div id="search" style="display: none;">';
					$search .= get_search_form( $echo = false );
					$search .= '</div></li>';
				endif;

				$button = '';
				if ( $options['nav_btn'] && (!empty( $options['nav_btn_url'] ) && !empty( $options['nav_btn_txt'] ) ) ) :

					$button = '<li><a href="'. esc_url( $options['nav_btn_url'] ) .'"  class="custom-button">'
				. esc_html( $options['nav_btn_txt'] ) .'</a>
				</li>';
			endif;

			$button .= $search;

			wp_nav_menu( array(
				'theme_location' => 'primary',
				'container' => 'div',
				'menu_class' => 'menu nav-menu',
				'menu_id' => 'primary-menu',
				'echo' => true,
				'fallback_cb' => 'charity_give_menu_fallback_cb',
				'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s'  . $button . '</ul>',
			) );
			?>
		</nav><!-- #site-navigation -->
	</div><!-- .wrapper -->
</header><!-- #masthead -->
<?php
}
endif;
	add_action( 'charity_give_header_action', 'charity_give_site_branding', 10 );

	if ( ! function_exists( 'charity_give_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since  Charity Give 1.0.0
	 *
	 */
	function charity_give_content_start() {
		?>
		<div id="content" class="site-content">
			<?php
		}
	endif;
	add_action( 'charity_give_content_start_action', 'charity_give_content_start', 10 );

	if ( ! function_exists( 'charity_give_header_image' ) ) :
    /**
     * Header Image codes
     *
     * @since  Charity Give 1.0.0
     *
     */
    function charity_give_header_image() {
    	if ( charity_give_is_frontpage() )
    		return;
    	$header_image = get_header_image();
        /*if ( is_singular() ) :
            $header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
        endif;*/
        ?>

        <div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
        	<div class="overlay"></div>
        	<div class="wrapper">
        		<header class="page-header">
        			<?php charity_give_custom_header_banner_title(); ?>
        		</header>
        		<?php charity_give_add_breadcrumb(); ?>
        	</div>
        </div><!-- #page-site-header -->

        <?php
    }
endif;
add_action( 'charity_give_header_image_action', 'charity_give_header_image', 10 );

if ( ! function_exists( 'charity_give_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since  Charity Give 1.0.0
	 */
	function charity_give_add_breadcrumb() {
		$options = charity_give_get_theme_options();

		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( charity_give_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * charity_give_simple_breadcrumb hook
				 *
				 * @hooked charity_give_simple_breadcrumb -  10
				 *
				 */
				do_action( 'charity_give_simple_breadcrumb' );
				echo '</div><!-- #breadcrumb-list -->';
			}
		endif;

		if ( ! function_exists( 'charity_give_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since  Charity Give 1.0.0
	 *
	 */
	function charity_give_content_end() {
		?>
	</div><!-- #content -->
	<?php
}
endif;
add_action( 'charity_give_content_end_action', 'charity_give_content_end', 10 );

if ( ! function_exists( 'charity_give_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  Charity Give 1.0.0
	 *
	 */
	function charity_give_footer_start() {
		$options = charity_give_get_theme_options();

		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
			<?php
		}
	endif;
	add_action( 'charity_give_footer', 'charity_give_footer_start', 10 );

	if ( ! function_exists( 'charity_give_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  Charity Give 1.0.0
	 *
	 */
	function charity_give_footer_site_info() {
		$options = charity_give_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

		$replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

		$options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text'];
		?>
		<div class="site-info">
			<div class="wrapper">
				<span>
					<?php 
					echo charity_give_santize_allow_tag( $copyright_text ); 
					if ( function_exists( 'the_privacy_policy_link' ) ) {
						the_privacy_policy_link( ' | ' );
					}
					?>
				</span>
			</div><!-- .wrapper -->    
		</div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'charity_give_footer', 'charity_give_footer_site_info', 40 );

if ( ! function_exists( 'charity_give_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  Charity Give 1.0.0
	 *
	 */
	function charity_give_footer_scroll_to_top() {
		$options  = charity_give_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo charity_give_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'charity_give_footer', 'charity_give_footer_scroll_to_top', 40 );


if ( ! function_exists( 'charity_give_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since  Charity Give 1.0.0
	 *
	 */
	function charity_give_loader() {
		$options = charity_give_get_theme_options();
		if ( $options['loader_enable'] ) { ?>

			<div id="loader">
				<div class="loader-container">
					<?php if ( 'default' == $options['loader_icon'] ) : ?>
						<div id="preloader">
							<span></span>
							<span></span>
							<span></span>
							<span></span>
							<span></span>
						</div>
					<?php else :
						echo charity_give_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
					endif; ?>
				</div>
			</div><!-- #loader -->
		<?php }
	}
endif;
add_action( 'charity_give_before_header', 'charity_give_loader', 10 );


if ( ! function_exists( 'charity_give_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since  Charity Give 1.0.0
	 *
	 */
	function charity_give_infinite_loader_spinner() { 
		global $post;
		$options = charity_give_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :			
			echo '<div class="blog-loader">' . charity_give_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';			
		endif;
	}
endif;
add_action( 'charity_give_infinite_loader_spinner_action', 'charity_give_infinite_loader_spinner', 10 );
